@@ -118,7 +118,7 @@ def DMoN_Clustering(features_X, features_position, r_max = 0.00034, n_clusters =
 
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
 
-def visualize_map_sample(areas_to_points, clusters, min_supp, features, max_samples_per_clusters):
+def visualize_map_sample(areas_to_points, min_supp, max_samples_per_clusters):
     COLORS_9_SET = [plt.cm.Set1(i) for i in range(10)]
     COLORS_9_SET = [cl.to_hex(c) for c in COLORS_9_SET]
 
