@@ -4,10 +4,6 @@ from scipy import spatial
 
 def rings(features_X, features_position, max_radio=[0.00014, 0.00024, 0.00034], max_neighbors_per_radio=[200, 500, 1000], keep_original_value=True, leafsize=10):
 
-    # Variables en anillos concentricos.
-    max_radio = [0.00014, 0.00024, 0.00034]
-    max_neighbors_per_radio = [200, 500, 1000]
-
     """
     El algoritmo toma todos los puntos dentro de un radio máximo.
     Luego, toma los K vecinos más cercanos a cada pundo donde K
